Package: RcppBDT
Type: Package
Title: 'Rcpp' Bindings for the Boost Date_Time Library
Version: 0.2.8
Date: 2026-03-12
Authors@R: c(person("Dirk", "Eddelbuettel", role = c("aut", "cre"), email = "edd@debian.org",
                    comment = c(ORCID = "0000-0001-6419-907X")),
             person("Romain", "Francois", role = "aut",
                    comment = c(ORCID = "0000-0002-2444-4226")))
Description: Access to Boost Date_Time functionality for dates,
 durations (both for days and date time objects), time zones, and 
 posix time ('ptime') is provided by using 'Rcpp modules'. The 
 posix time implementation can support high-resolution of up to 
 nano-second  precision by using 96 bits (instead of 64 with R)
 to present a 'ptime' object (but this needs recompilation with
 a #define set).
License: GPL (>= 2)
LazyLoad: yes
Imports: Rcpp, methods
LinkingTo: Rcpp, BH
URL: https://github.com/eddelbuettel/rcppbdt,
        https://dirk.eddelbuettel.com/code/rcpp.bdt.html
BugReports: https://github.com/eddelbuettel/rcppbdt/issues
RoxygenNote: 6.0.1
NeedsCompilation: yes
Packaged: 2026-03-12 10:24:20 UTC; edd
Author: Dirk Eddelbuettel [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6419-907X>),
  Romain Francois [aut] (ORCID: <https://orcid.org/0000-0002-2444-4226>)
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-03-12 10:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 19:41:28 UTC; unix
Archs: RcppBDT.so.dSYM
