
import(Rcpp,methods)                    # packages we require

useDynLib(RcppBDT, .registration=TRUE)  # this package's shared library

exportPattern("^[[:alpha:]]+")          # export all identifier (eg the convenience function and consts)
exportMethods("format",                 # all modules have format and show methods defined
              "show")
